@@ -30,7 +30,7 @@ func (h *handler) workspaceDidChangeWatchedFiles(ctx context.Context, conn *json
 		return nil, err
 	}
 
-	log.Printf("Notify `textDocument/publishDiagnostics` with `%#v`", diagnostics)
+	log.Printf("Notify textDocument/publishDiagnostics with %#v", diagnostics)
 	for path, diags := range diagnostics {
 		err = conn.Notify(
 			ctx,
@@ -41,7 +41,7 @@ func (h *handler) workspaceDidChangeWatchedFiles(ctx context.Context, conn *json
 			},
 		)
 		if err != nil {
-			return nil, fmt.Errorf("Failed to notify `textDocument/publishDiagnostics`: %s", err)
+			return nil, fmt.Errorf("Failed to notify textDocument/publishDiagnostics: %s", err)
 		}
 	}
 
